Package: RBGL
Version: 1.86.0
Title: An interface to the BOOST graph library
Authors@R: c(
        person("Vince", "Carey", role = "aut",
                email = "stvjc@channing.harvard.edu"),
        person("Li", "Long",  role = "aut",
                email = "li.long@isb-sib.ch"),
        person("R.", "Gentleman", role = "aut"),
        person("Emmanuel", "Taiwo", role = "ctb", 
                comment = "Converted RBGL vignette from Sweave to RMarkdown / HTML."),
        person("Bioconductor Package Maintainer", role = "cre",
                email = "maintainer@bioconductor.org"))
Depends: graph, methods
Imports: methods
Suggests: Rgraphviz, XML, RUnit, BiocGenerics, BiocStyle, knitr
Description: A fairly extensive and comprehensive interface to the
        graph algorithms contained in the BOOST library.
License: Artistic-2.0
URL: http://www.bioconductor.org
LazyLoad: yes
biocViews: GraphAndNetwork, Network
LinkingTo: BH
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/RBGL
git_branch: RELEASE_3_22
git_last_commit: a15bdde
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: yes
Packaged: 2025-10-30 05:58:03 UTC; biocbuild
Author: Vince Carey [aut],
  Li Long [aut],
  R. Gentleman [aut],
  Emmanuel Taiwo [ctb] (Converted RBGL vignette from Sweave to RMarkdown
    / HTML.),
  Bioconductor Package Maintainer [cre]
Maintainer: Bioconductor Package Maintainer <maintainer@bioconductor.org>
